@@ -4,10 +4,9 @@ import climetlab as cml
 from climetlab import Dataset
 from climetlab.normalize import normalize_args
 
-from . import DATA, URL
-from .fields import S2sMerger
+from . import DATA, URL, S2sVariableMerger
 
-PATTERN = "{url}/{data}/{dataset}/{parameter}-weeks-{weeks}.nc"
+PATTERN = "{url}/{data}/{dataset}/{parameter}.nc"
 
 
 def benchmark_builder(datasetname):
@@ -21,16 +20,15 @@ def benchmark_builder(datasetname):
 
         @normalize_args(
             parameter="variable-list(cf)",
-            weeks=["34", "56", ["34"], ["56"], ["34", "56"]],
         )
-        def __init__(self, parameter, weeks):
+        def __init__(self, parameter):
             self.dataset = datasetname
-            request = dict(url=URL, data=DATA, weeks=weeks, parameter=parameter, dataset=self.dataset)
+            request = dict(url=URL, data=DATA, parameter=parameter, dataset=self.dataset)
             self.source = cml.load_source(
                 "url-pattern",
                 PATTERN,
                 request,
-                merger=S2sMerger(engine="netcdf4", concat_dim="weeks"),
+                merger=S2sVariableMerger(),
             )
 
     return Benchmark
